/*
 * Copyright (C) 2021 European Spallation Source ERIC.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.openepics.names;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.context.annotation.Bean;

import io.swagger.v3.oas.models.ExternalDocumentation;
import io.swagger.v3.oas.models.OpenAPI;
import io.swagger.v3.oas.models.info.Contact;
import io.swagger.v3.oas.models.info.Info;
import io.swagger.v3.oas.models.info.License;

@SpringBootApplication
public class NamingApplication {

    public static void main(String[] args) {
        SpringApplication.run(NamingApplication.class, args);
    }

    @Value("${openapi.externaldocs.description}") String openapi_externaldocs_description;
    @Value("${openapi.externaldocs.url}") String openapi_externaldocs_url;
    @Value("${openapi.info.contact.email}") String openapi_info_contact_email;
    @Value("${openapi.info.contact.name}") String openapi_info_contact_name;
    @Value("${openapi.info.contact.url}") String openapi_info_contact_url;
    @Value("${openapi.info.description}") String openapi_info_description;
    @Value("${openapi.info.license.name}") String openapi_info_license_name;
    @Value("${openapi.info.title}") String openapi_info_title;

    @Bean
    public OpenAPI customOpenAPI(@Value("${app.version}") String appVersion) {
        return new OpenAPI()
                .externalDocs(new ExternalDocumentation()
                        .description(openapi_externaldocs_description)
                        .url(openapi_externaldocs_url))
                .info(new Info()
                        .contact(new Contact()
                                .email(openapi_info_contact_email)
                                .name(openapi_info_contact_name)
                                .url(openapi_info_contact_url))
                        .description(openapi_info_description)
                        .license(new License().name(openapi_info_license_name))
                        .title(openapi_info_title)
                        .version(appVersion));
    }

}
